<?php
/**
 * This file contains the class for registering the plugin's settings page.
 *
 * @package    Nelio_AB_Testing
 * @subpackage Nelio_AB_Testing/admin/pages
 * @author     David Aguilera <david.aguilera@neliosoftware.com>
 * @since      5.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Class that registers the plugin's settings page.
 *
 * @package    Nelio_AB_Testing
 * @subpackage Nelio_AB_Testing/admin/pages
 * @author     David Aguilera <david.aguilera@neliosoftware.com>
 * @since      5.0.0
 */
class Nelio_AB_Testing_Settings_Page extends Nelio_AB_Testing_Abstract_Page {

	public function __construct() {

		parent::__construct(
			'nelio-ab-testing',
			_x( 'Settings', 'text', 'nelio-ab-testing' ),
			_x( 'Settings', 'text', 'nelio-ab-testing' ),
			'edit_others_posts',
			'nelio-ab-testing-settings'
		);

	}//end __construct()

	// @Implements
	public function enqueue_assets() {

		$screen = get_current_screen();
		if ( 'nelio-a-b-testing_page_nelio-ab-testing-settings' !== $screen->id ) {
			return;
		}//end if

		$settings = Nelio_AB_Testing_Settings::instance();
		wp_enqueue_script( $settings->get_generic_script_name() );

		$script = <<<JS
		( function() {
			wp.domReady( function() {
				nab.initPage( %s );
			} );
		} )();
JS;

		$settings = array(
			'siteId'       => nab_get_site_id(),
			'subscription' => nab_get_subscription(),
			'help'         => array(
				array(
					'label' => _x( 'After starting an A/B test, some parameters appear in my URLs. What are they?', 'text', 'nelio-ab-testing' ),
					'link'  => _x( 'https://neliosoftware.com/testing/help/after-starting-an-ab-test-some-parameters-appear-in-my-urls-what-are-they/', 'text', 'nelio-ab-testing' ),
				),
				array(
					'label' => _x( 'How can I hide A/B testing parameters from my URLs?', 'text', 'nelio-ab-testing' ),
					'link'  => _x( 'https://neliosoftware.com/testing/help/how-can-i-hide-ab-testing-parameters-from-my-urls/', 'text', 'nelio-ab-testing' ),
				),
				array(
					'label' => _x( 'How do I purchase additional quota?', 'text', 'nelio-ab-testing' ),
					'link'  => _x( 'https://neliosoftware.com/testing/help/how-to-purchase-quota/', 'text', 'nelio-ab-testing' ),
				),
			),
		);

		wp_enqueue_style(
			'nab-settings-page',
			nelioab()->plugin_url . '/assets/dist/css/settings-page.css',
			[ 'nab-components' ],
			nelioab()->plugin_version
		);
		nab_enqueue_script_with_auto_deps( 'nab-settings-page', 'settings-page', true );

		wp_add_inline_script(
			'nab-settings-page',
			sprintf(
				$script,
				wp_json_encode( $settings )
			)
		);

	}//end enqueue_assets()

	// @Implements
	public function display() {
		require_once nelioab()->plugin_path . '/admin/views/nelio-ab-testing-settings-page.php';
	}//end display()

}//end class
