<?php

namespace Nelio_AB_Testing\Experiment_Library\Compat\Leadpages;

defined( 'ABSPATH' ) || exit;

function fix_leadpages_slug_in_alternative_during_its_creation( $alternative ) {

	$post_id = $alternative['postId'];
	$post    = get_post( $post_id );

	fix_leadpages_slug_in_alternative( $post_id, $post );

	return $alternative;

}//end fix_leadpages_slug_in_alternative_during_its_creation()

function fix_leadpages_slug_in_alternative( $post_id, $post ) {

	if ( 'leadpages_post' !== $post->post_type ) {
		return;
	}//end if

	if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
		return;
	}//end if

	fix_nab_permalink( $post );

	$experiment = get_post_meta( $post_id, '_nab_experiment', true );
	if ( empty( $experiment ) ) {
		return;
	}//end if

	update_post_meta( $post_id, 'leadpages_slug', "nab-alternative-leadpage-{$experiment}-{$post_id}" );

}//end fix_leadpages_slug_in_alternative()

function fix_nab_permalink_when_saving_experiment( $experiment ) {

	if ( 'nab/custom-post-type' !== $experiment->get_type() ) {
		return;
	}//end if

	$control = $experiment->get_alternative( 'control' );
	if ( empty( $control ) || ! isset( $control['attributes'] ) ) {
		return;
	}//end if

	$control = $control['attributes'];
	if ( ! isset( $control['postType'] ) ) {
		return;
	}//end if

	if ( 'leadpages_post' !== $control['postType'] ) {
		return;
	}//end if

	$post = get_post( $control['postId'] );
	if ( empty( $post ) || is_wp_error( $post ) ) {
		return;
	}//end if

	fix_nab_permalink( $post );

}//end fix_nab_permalink_when_saving_experiment()

function fix_nab_permalink( $post ) {

	if ( 'leadpages_post' !== $post->post_type ) {
		return;
	}//end if

	$slug = get_post_meta( $post->ID, 'leadpages_slug', true );
	if ( empty( $slug ) ) {
		return;
	}//end if

	$experiment = get_post_meta( $post->ID, '_nab_experiment', true );
	if ( ! empty( $experiment ) ) {
		return;
	}//end if

	$permalink = get_permalink( $post );
	$permalink = str_replace( '/leadpages_post/', '', $permalink );
	$permalink = str_replace( "/{$post->post_name}/", "/{$slug}/", $permalink );
	update_post_meta( $post->ID, '_nab_permalink', $permalink );

}//end fix_nab_permalink()

function prevent_alternative_front_leadpage_from_overwriting_control( $value, $old_value ) {

	$post_id = absint( $value );
	if ( ! $post_id ) {
		return $value;
	}//end if

	$experiment = get_post_meta( $post_id, '_nab_experiment', true );
	if ( empty( $experiment ) ) {
		return $value;
	}//end if

	return $old_value;

}//end prevent_alternative_front_leadpage_from_overwriting_control()

add_action(
	'plugins_loaded',
	function() {

		if ( ! class_exists( 'LeadpagesWP\Admin\CustomPostTypes\LeadpagesPostType' ) ) {
			return;
		}//end if

		add_action( 'nab_save_experiment', __NAMESPACE__ . '\fix_nab_permalink_when_saving_experiment', 99 );

		add_filter( 'nab_nab/custom-post-type_create_alternative_content', __NAMESPACE__ . '\fix_leadpages_slug_in_alternative_during_its_creation', 99 );
		add_action( 'save_post', __NAMESPACE__ . '\fix_leadpages_slug_in_alternative', 99, 2 );

		add_filter( 'pre_update_option_leadpages_front_page_id', __NAMESPACE__ . '\prevent_alternative_front_leadpage_from_overwriting_control', 99, 2 );

	}
);

