<?php

namespace Nelio_AB_Testing\Experiment_Library\Post_Experiment;

defined( 'ABSPATH' ) || exit;

use \add_action;
use \add_filter;

function load_alternative( $alternative, $control ) {

	if ( $control['postId'] === $alternative['postId'] ) {
		return;
	}//end if

	add_filter(
		'single_post_title',
		function( $post_title, $post ) use ( $control, $alternative ) {
			if ( $post->ID !== $control['postId'] ) {
				return $post_title;
			}//end if
			$post = get_post( $alternative['postId'] );
			return $post->post_title;
		},
		10,
		2
	);

	$replace_post_results = function( $posts ) use ( &$replace_post_results, $alternative, $control ) {

		return array_map(
			function ( $post ) use ( &$replace_post_results, $alternative, $control ) {

				if ( $post->ID !== $control['postId'] ) {
					return $post;
				}//end if

				remove_filter( 'posts_results', $replace_post_results );
				$post              = get_post( $alternative['postId'] );
				$post->post_status = 'publish';

				/**
				 * Whether we should use the original post ID when loading an alternative post or not.
				 *
				 * @param boolean $use_control_id whether we should use the original post ID or not.
				 *                                Default: `true`.
				 *
				 * @since 5.0.4
				 */
				if ( apply_filters( 'nab_use_control_id_in_alternative', true ) ) {
					$post->ID = $control['postId'];
				}//end if

				if ( is_singular() && is_main_query() ) {
					global $wp_query;
					$wp_query->queried_object    = $post;
					$wp_query->queried_object_id = $post->ID;
				}//end if

				add_filter( 'posts_results', $replace_post_results );
				return $post;

			},
			$posts
		);

	};
	add_filter( 'posts_results', $replace_post_results );

	$fix_link = function( $permalink, $post_id ) use ( $alternative, $control ) {

		if ( ! is_int( $post_id ) ) {
			if ( is_object( $post_id ) && isset( $post_id->ID ) ) {
				$post_id = $post_id->ID;
			} else {
				$post_id = url_to_postid( $permalink );
			}//end if
		}//end if

		if ( $post_id !== $alternative['postId'] ) {
			return $permalink;
		}//end if

		return get_permalink( $control['postId'] );

	};
	add_filter( 'post_link', $fix_link, 10, 2 );
	add_filter( 'page_link', $fix_link, 10, 2 );
	add_filter( 'post_type_link', $fix_link, 10, 2 );

	$fix_shortlink = function( $shortlink, $post_id ) use ( $alternative, $control ) {

		if ( empty( $post_id ) ) {
			$post_id = get_the_ID();
		}//end if

		if ( $post_id !== $alternative['postId'] ) {
			return $shortlink;
		}//end if

		return wp_get_shortlink( $control['postId'] );
	};
	add_filter( 'get_shortlink', $fix_shortlink, 10, 2 );

	$use_alternative_metas = function( $value, $object_id, $meta_key, $single ) use ( &$use_alternative_metas, $alternative, $control ) {
		if ( $object_id !== $control['postId'] ) {
			return $value;
		}//end if
		$value = get_post_meta( $alternative['postId'], $meta_key, $single );
		return $value;
	};
	add_filter( 'get_post_metadata', $use_alternative_metas, 1, 4 );

	add_filter(
		'nav_menu_item_title',
		function( $title, $item ) use ( $alternative, $control ) {

			if ( ! empty( $item->post_title ) ) {
				return $title;
			}//end if

			if ( "{$control['postId']}" !== "{$item->object_id}" ) {
				return $title;
			}//end if

			$post = get_post( $alternative['postId'] );
			if ( ! $post || is_wp_error( $post ) ) {
				return $title;
			}//end if

			return $post->post_title;

		},
		10,
		2
	);

	add_filter(
		'comments_template_query_args',
		function( $query ) use ( $control ) {
			return wp_parse_args(
				array(
					'post_id' => $control['postId'],
				),
				$query
			);
		}
	);

	add_filter(
		'get_comments_number',
		function( $count ) use ( $alternative, $control ) {

			if ( get_the_ID() !== $control['postId'] ) {
				return $count;
			}//end if

			$aux = get_post( $control['postId'] );
			return $aux->comment_count;

		}
	);

}//end load_alternative()
add_action( 'nab_nab/page_load_alternative', __NAMESPACE__ . '\load_alternative', 10, 2 );
add_action( 'nab_nab/post_load_alternative', __NAMESPACE__ . '\load_alternative', 10, 2 );
add_action( 'nab_nab/custom-post-type_load_alternative', __NAMESPACE__ . '\load_alternative', 10, 2 );

