<?php

namespace Nelio_AB_Testing\Experiment_Library\Template_Experiment;

defined( 'ABSPATH' ) || exit;

use \add_action;
use \add_filter;

function maybe_exclude_experiment_from_loading( $is_excluded, $control ) {

	if ( ! is_singular() ) {
		return true;
	}//end if

	if ( get_post_type() !== $control['postType'] ) {
		return true;
	}//end if

	$current_template = get_post_meta( get_the_ID(), '_wp_page_template', true );
	if ( empty( $current_template ) || 'default' === $current_template ) {
		$current_template = '_nab_default_template';
	}//end if

	if ( $control['templateId'] !== $current_template ) {
		return true;
	}//end if

	return $is_excluded;

}//end maybe_exclude_experiment_from_loading()
add_action( 'nab_nab/template_exclude_experiment_from_loading', __NAMESPACE__ . '\maybe_exclude_experiment_from_loading', 10, 2 );

function load_alternative( $alternative, $control ) {

	if ( $alternative['templateId'] === $control['templateId'] ) {
		return;
	}//end if

	$hook_type = 'single';
	if ( 'page' === $control['postType'] ) {
		$hook_type = 'page';
	}//end if

	if ( '_nab_default_template' === $alternative['templateId'] ) {
		add_filter_to_remove_control_template( $hook_type, $control['templateId'] );
		return;
	}//end if

	if ( '_nab_default_template' === $control['templateId'] ) {
		add_filter_to_switch_default_template_to_alternative_in_post_type( $hook_type, $alternative['templateId'], $control['postType'] );
	} else {
		add_filter_to_switch_templates( $hook_type, $control['templateId'], $alternative['templateId'] );
	}//end if

	add_filter_to_fix_switched_templates( $hook_type );

}//end load_alternative()
add_action( 'nab_nab/template_load_alternative', __NAMESPACE__ . '\load_alternative', 10, 2 );

function add_filter_to_remove_control_template( $hook_type, $control_template ) {

	add_filter(
		"{$hook_type}_template_hierarchy",
		function ( $templates ) use ( $control_template ) {

			return array_values(
				array_filter(
					$templates,
					function ( $template ) use ( $control_template ) {
						return $template !== $control_template;
					}
				)
			);

		}
	);

}//end add_filter_to_remove_control_template()

function add_filter_to_switch_default_template_to_alternative_in_post_type( $hook_type, $alternative_template, $post_type ) {

	add_filter(
		"{$hook_type}_template_hierarchy",
		function ( $templates ) use ( $alternative_template, $post_type ) {

			return array_values(
				array_unique(
					array_map(
						function ( $template ) use ( $alternative_template, $post_type ) {
							if ( 0 !== strpos( $template, $post_type ) ) {
								return $template;
							}//end if
							return '_nab_change_' . $alternative_template;
						},
						$templates
					)
				)
			);

		}
	);

}//end add_filter_to_switch_default_template_to_alternative_in_post_type()

function add_filter_to_switch_templates( $hook_type, $control_template, $alternative_template ) {

	add_filter(
		"{$hook_type}_template_hierarchy",
		function ( $templates ) use ( $control_template, $alternative_template ) {

			return array_values(
				array_unique(
					array_map(
						function ( $template ) use ( $control_template, $alternative_template ) {
							if ( $template !== $control_template ) {
								return $template;
							}//end if
							return '_nab_change_' . $alternative_template;
						},
						$templates
					)
				)
			);

		}
	);

}//end add_filter_to_switch_templates()

function add_filter_to_fix_switched_templates( $hook_type ) {

	add_filter(
		"{$hook_type}_template_hierarchy",
		function( $templates ) {
			return array_map(
				function ( $template ) {
					return preg_replace( '/^_nab_change_/', '', $template );
				},
				$templates
			);
		},
		99
	);

}//end add_filter_to_fix_switched_templates()

